#pragma once

#include "debug.hpp"

#include <string>

//! @brief separated namespace to embed all libknx related classes
namespace knx
{

/**
 * @brief This class represents the configuration of the knx connection.
 */
class KNX_IMPORT_EXPORT config
{
public:
    /**
     * @brief constructor taking all command line arguments
     */
    config(int argc, char* argv[]);
    /**
     * @brief empty descructor
     */
    ~config();

    //! @brief name or ip address of the local host (control connection)
    std::string local_control_host;

    //! @brief communication port for control messages
    int local_control_port;

    //! @brief name or ip address of the local host (data connection)
    std::string local_data_host;

    //! @brief communication port for data messages
    int local_data_port;

    //! @brief name or ip address of the knx gateway
    std::string remote_host;

    //! @brief port of the gateway (default 3671)
    int remote_port;

    //! @brief name of the logging file
    std::string logging_filename;

    //! @brief indication if logging is active
    bool logging_activated;
};

}
